# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import ai_meme_create_params, ai_meme_generate_params, ai_meme_retrieve_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.ai_meme_create_response import AIMemeCreateResponse
from ..types.ai_meme_generate_response import AIMemeGenerateResponse
from ..types.ai_meme_retrieve_response import AIMemeRetrieveResponse

__all__ = ["AIMemesResource", "AsyncAIMemesResource"]


class AIMemesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AIMemesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AIMemesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AIMemesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AIMemesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        image_url: str | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AIMemeCreateResponse:
        """
        获取表情包数据

        Args:
          image_url: 图片地址

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/ai-meme",
            body=maybe_transform(
                {
                    "image_url": image_url,
                    "session_id": session_id,
                },
                ai_meme_create_params.AIMemeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AIMemeCreateResponse,
        )

    def retrieve(
        self,
        *,
        limit: int | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AIMemeRetrieveResponse:
        """
        获取用户历史表情包数据列表

        Args:
          limit: 每页数量

          page: 页数

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/ai-meme",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    ai_meme_retrieve_params.AIMemeRetrieveParams,
                ),
            ),
            cast_to=AIMemeRetrieveResponse,
        )

    def generate(
        self,
        *,
        context_index: int | NotGiven = NOT_GIVEN,
        meme_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AIMemeGenerateResponse:
        """
        获取 AI 表情包

        Args:
          context_index: 文案序号

          meme_id: 表情包 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/ai-meme/generate",
            body=maybe_transform(
                {
                    "context_index": context_index,
                    "meme_id": meme_id,
                },
                ai_meme_generate_params.AIMemeGenerateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AIMemeGenerateResponse,
        )


class AsyncAIMemesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAIMemesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAIMemesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAIMemesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncAIMemesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        image_url: str | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AIMemeCreateResponse:
        """
        获取表情包数据

        Args:
          image_url: 图片地址

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/ai-meme",
            body=await async_maybe_transform(
                {
                    "image_url": image_url,
                    "session_id": session_id,
                },
                ai_meme_create_params.AIMemeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AIMemeCreateResponse,
        )

    async def retrieve(
        self,
        *,
        limit: int | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AIMemeRetrieveResponse:
        """
        获取用户历史表情包数据列表

        Args:
          limit: 每页数量

          page: 页数

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/ai-meme",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    ai_meme_retrieve_params.AIMemeRetrieveParams,
                ),
            ),
            cast_to=AIMemeRetrieveResponse,
        )

    async def generate(
        self,
        *,
        context_index: int | NotGiven = NOT_GIVEN,
        meme_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AIMemeGenerateResponse:
        """
        获取 AI 表情包

        Args:
          context_index: 文案序号

          meme_id: 表情包 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/ai-meme/generate",
            body=await async_maybe_transform(
                {
                    "context_index": context_index,
                    "meme_id": meme_id,
                },
                ai_meme_generate_params.AIMemeGenerateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AIMemeGenerateResponse,
        )


class AIMemesResourceWithRawResponse:
    def __init__(self, ai_memes: AIMemesResource) -> None:
        self._ai_memes = ai_memes

        self.create = to_raw_response_wrapper(
            ai_memes.create,
        )
        self.retrieve = to_raw_response_wrapper(
            ai_memes.retrieve,
        )
        self.generate = to_raw_response_wrapper(
            ai_memes.generate,
        )


class AsyncAIMemesResourceWithRawResponse:
    def __init__(self, ai_memes: AsyncAIMemesResource) -> None:
        self._ai_memes = ai_memes

        self.create = async_to_raw_response_wrapper(
            ai_memes.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            ai_memes.retrieve,
        )
        self.generate = async_to_raw_response_wrapper(
            ai_memes.generate,
        )


class AIMemesResourceWithStreamingResponse:
    def __init__(self, ai_memes: AIMemesResource) -> None:
        self._ai_memes = ai_memes

        self.create = to_streamed_response_wrapper(
            ai_memes.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            ai_memes.retrieve,
        )
        self.generate = to_streamed_response_wrapper(
            ai_memes.generate,
        )


class AsyncAIMemesResourceWithStreamingResponse:
    def __init__(self, ai_memes: AsyncAIMemesResource) -> None:
        self._ai_memes = ai_memes

        self.create = async_to_streamed_response_wrapper(
            ai_memes.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            ai_memes.retrieve,
        )
        self.generate = async_to_streamed_response_wrapper(
            ai_memes.generate,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["AIMemeRetrieveParams"]


class AIMemeRetrieveParams(TypedDict, total=False):
    limit: int
    """每页数量"""

    page: int
    """页数"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["CheckPointCreateParams"]


class CheckPointCreateParams(TypedDict, total=False):
    action: str
    """埋点动作"""

    code: str
    """微信 code"""

    page_path: str
    """页面路径"""

    related_id: str
    """关联 id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMagnumKeys:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_get_key(self, client: Czlai) -> None:
        magnum_key = client.magnum_keys.get_key()
        assert magnum_key is None

    @parametrize
    def test_method_get_key_with_all_params(self, client: Czlai) -> None:
        magnum_key = client.magnum_keys.get_key(
            context="context",
        )
        assert magnum_key is None

    @parametrize
    def test_raw_response_get_key(self, client: Czlai) -> None:
        response = client.magnum_keys.with_raw_response.get_key()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        magnum_key = response.parse()
        assert magnum_key is None

    @parametrize
    def test_streaming_response_get_key(self, client: Czlai) -> None:
        with client.magnum_keys.with_streaming_response.get_key() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            magnum_key = response.parse()
            assert magnum_key is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_picture_choice(self, client: Czlai) -> None:
        magnum_key = client.magnum_keys.picture_choice(
            img_url="img_url",
        )
        assert magnum_key is None

    @parametrize
    def test_method_picture_choice_with_all_params(self, client: Czlai) -> None:
        magnum_key = client.magnum_keys.picture_choice(
            img_url="img_url",
            key_usage_id="key_usage_id",
            user_uuid="user_uuid",
        )
        assert magnum_key is None

    @parametrize
    def test_raw_response_picture_choice(self, client: Czlai) -> None:
        response = client.magnum_keys.with_raw_response.picture_choice(
            img_url="img_url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        magnum_key = response.parse()
        assert magnum_key is None

    @parametrize
    def test_streaming_response_picture_choice(self, client: Czlai) -> None:
        with client.magnum_keys.with_streaming_response.picture_choice(
            img_url="img_url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            magnum_key = response.parse()
            assert magnum_key is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_picture_question(self, client: Czlai) -> None:
        magnum_key = client.magnum_keys.picture_question(
            img_url="img_url",
        )
        assert magnum_key is None

    @parametrize
    def test_method_picture_question_with_all_params(self, client: Czlai) -> None:
        magnum_key = client.magnum_keys.picture_question(
            img_url="img_url",
            key_usage_id="key_usage_id",
            user_uuid="user_uuid",
        )
        assert magnum_key is None

    @parametrize
    def test_raw_response_picture_question(self, client: Czlai) -> None:
        response = client.magnum_keys.with_raw_response.picture_question(
            img_url="img_url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        magnum_key = response.parse()
        assert magnum_key is None

    @parametrize
    def test_streaming_response_picture_question(self, client: Czlai) -> None:
        with client.magnum_keys.with_streaming_response.picture_question(
            img_url="img_url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            magnum_key = response.parse()
            assert magnum_key is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_voice_choice(self, client: Czlai) -> None:
        magnum_key = client.magnum_keys.voice_choice(
            message="message",
        )
        assert magnum_key is None

    @parametrize
    def test_method_voice_choice_with_all_params(self, client: Czlai) -> None:
        magnum_key = client.magnum_keys.voice_choice(
            message="message",
            key_usage_id="key_usage_id",
            user_uuid="user_uuid",
        )
        assert magnum_key is None

    @parametrize
    def test_raw_response_voice_choice(self, client: Czlai) -> None:
        response = client.magnum_keys.with_raw_response.voice_choice(
            message="message",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        magnum_key = response.parse()
        assert magnum_key is None

    @parametrize
    def test_streaming_response_voice_choice(self, client: Czlai) -> None:
        with client.magnum_keys.with_streaming_response.voice_choice(
            message="message",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            magnum_key = response.parse()
            assert magnum_key is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_voice_question(self, client: Czlai) -> None:
        magnum_key = client.magnum_keys.voice_question(
            message="message",
        )
        assert magnum_key is None

    @parametrize
    def test_method_voice_question_with_all_params(self, client: Czlai) -> None:
        magnum_key = client.magnum_keys.voice_question(
            message="message",
            key_usage_id="key_usage_id",
            pet_id=0,
            user_uuid="user_uuid",
        )
        assert magnum_key is None

    @parametrize
    def test_raw_response_voice_question(self, client: Czlai) -> None:
        response = client.magnum_keys.with_raw_response.voice_question(
            message="message",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        magnum_key = response.parse()
        assert magnum_key is None

    @parametrize
    def test_streaming_response_voice_question(self, client: Czlai) -> None:
        with client.magnum_keys.with_streaming_response.voice_question(
            message="message",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            magnum_key = response.parse()
            assert magnum_key is None

        assert cast(Any, response.is_closed) is True


class TestAsyncMagnumKeys:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_get_key(self, async_client: AsyncCzlai) -> None:
        magnum_key = await async_client.magnum_keys.get_key()
        assert magnum_key is None

    @parametrize
    async def test_method_get_key_with_all_params(self, async_client: AsyncCzlai) -> None:
        magnum_key = await async_client.magnum_keys.get_key(
            context="context",
        )
        assert magnum_key is None

    @parametrize
    async def test_raw_response_get_key(self, async_client: AsyncCzlai) -> None:
        response = await async_client.magnum_keys.with_raw_response.get_key()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        magnum_key = await response.parse()
        assert magnum_key is None

    @parametrize
    async def test_streaming_response_get_key(self, async_client: AsyncCzlai) -> None:
        async with async_client.magnum_keys.with_streaming_response.get_key() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            magnum_key = await response.parse()
            assert magnum_key is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_picture_choice(self, async_client: AsyncCzlai) -> None:
        magnum_key = await async_client.magnum_keys.picture_choice(
            img_url="img_url",
        )
        assert magnum_key is None

    @parametrize
    async def test_method_picture_choice_with_all_params(self, async_client: AsyncCzlai) -> None:
        magnum_key = await async_client.magnum_keys.picture_choice(
            img_url="img_url",
            key_usage_id="key_usage_id",
            user_uuid="user_uuid",
        )
        assert magnum_key is None

    @parametrize
    async def test_raw_response_picture_choice(self, async_client: AsyncCzlai) -> None:
        response = await async_client.magnum_keys.with_raw_response.picture_choice(
            img_url="img_url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        magnum_key = await response.parse()
        assert magnum_key is None

    @parametrize
    async def test_streaming_response_picture_choice(self, async_client: AsyncCzlai) -> None:
        async with async_client.magnum_keys.with_streaming_response.picture_choice(
            img_url="img_url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            magnum_key = await response.parse()
            assert magnum_key is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_picture_question(self, async_client: AsyncCzlai) -> None:
        magnum_key = await async_client.magnum_keys.picture_question(
            img_url="img_url",
        )
        assert magnum_key is None

    @parametrize
    async def test_method_picture_question_with_all_params(self, async_client: AsyncCzlai) -> None:
        magnum_key = await async_client.magnum_keys.picture_question(
            img_url="img_url",
            key_usage_id="key_usage_id",
            user_uuid="user_uuid",
        )
        assert magnum_key is None

    @parametrize
    async def test_raw_response_picture_question(self, async_client: AsyncCzlai) -> None:
        response = await async_client.magnum_keys.with_raw_response.picture_question(
            img_url="img_url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        magnum_key = await response.parse()
        assert magnum_key is None

    @parametrize
    async def test_streaming_response_picture_question(self, async_client: AsyncCzlai) -> None:
        async with async_client.magnum_keys.with_streaming_response.picture_question(
            img_url="img_url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            magnum_key = await response.parse()
            assert magnum_key is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_voice_choice(self, async_client: AsyncCzlai) -> None:
        magnum_key = await async_client.magnum_keys.voice_choice(
            message="message",
        )
        assert magnum_key is None

    @parametrize
    async def test_method_voice_choice_with_all_params(self, async_client: AsyncCzlai) -> None:
        magnum_key = await async_client.magnum_keys.voice_choice(
            message="message",
            key_usage_id="key_usage_id",
            user_uuid="user_uuid",
        )
        assert magnum_key is None

    @parametrize
    async def test_raw_response_voice_choice(self, async_client: AsyncCzlai) -> None:
        response = await async_client.magnum_keys.with_raw_response.voice_choice(
            message="message",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        magnum_key = await response.parse()
        assert magnum_key is None

    @parametrize
    async def test_streaming_response_voice_choice(self, async_client: AsyncCzlai) -> None:
        async with async_client.magnum_keys.with_streaming_response.voice_choice(
            message="message",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            magnum_key = await response.parse()
            assert magnum_key is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_voice_question(self, async_client: AsyncCzlai) -> None:
        magnum_key = await async_client.magnum_keys.voice_question(
            message="message",
        )
        assert magnum_key is None

    @parametrize
    async def test_method_voice_question_with_all_params(self, async_client: AsyncCzlai) -> None:
        magnum_key = await async_client.magnum_keys.voice_question(
            message="message",
            key_usage_id="key_usage_id",
            pet_id=0,
            user_uuid="user_uuid",
        )
        assert magnum_key is None

    @parametrize
    async def test_raw_response_voice_question(self, async_client: AsyncCzlai) -> None:
        response = await async_client.magnum_keys.with_raw_response.voice_question(
            message="message",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        magnum_key = await response.parse()
        assert magnum_key is None

    @parametrize
    async def test_streaming_response_voice_question(self, async_client: AsyncCzlai) -> None:
        async with async_client.magnum_keys.with_streaming_response.voice_question(
            message="message",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            magnum_key = await response.parse()
            assert magnum_key is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .medical_record import MedicalRecord

__all__ = ["MedicalRecordRetrieveResponse"]


class MedicalRecordRetrieveResponse(BaseModel):
    data: Optional[MedicalRecord] = None

    message: Optional[str] = None

    success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["MagnumKeyPictureChoiceParams"]


class MagnumKeyPictureChoiceParams(TypedDict, total=False):
    img_url: Required[str]
    """图片 url"""

    key_usage_id: Optional[str]
    """会话 id"""

    user_uuid: Optional[str]
    """用户 uuid"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import (
    ai_trial_answer_params,
    ai_trial_report_params,
    ai_trial_history_params,
    ai_trial_summary_params,
    ai_trial_relation_params,
    ai_trial_session_start_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["AITrialResource", "AsyncAITrialResource"]


class AITrialResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AITrialResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AITrialResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AITrialResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AITrialResourceWithStreamingResponse(self)

    def answer(
        self,
        *,
        service_type: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        user_input: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        AI 聊天

        Args:
          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          user_input: 用户输入

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return self._post(
            "/ai-trial/answer",
            body=maybe_transform(
                {
                    "service_type": service_type,
                    "session_id": session_id,
                    "user_input": user_input,
                },
                ai_trial_answer_params.AITrialAnswerParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def history(
        self,
        *,
        content: str,
        role: str,
        session_id: str,
        content_type: int | NotGiven = NOT_GIVEN,
        module_type: int | NotGiven = NOT_GIVEN,
        stage: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        保存聊天记录

        Args:
          content: 内容

          role: 角色, 取值为其中之一 ==>[user, ai]

          session_id: 会话 id

          content_type: 1-文字 2-图文

          module_type: 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别

          stage: 1-用户主诉 2-用户回答 3-AI 提问 4-AI 病情小结 5-AI 病例报告 6-AI 输出 7-用户补充

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-trial/history",
            body=maybe_transform(
                {
                    "content": content,
                    "role": role,
                    "session_id": session_id,
                    "content_type": content_type,
                    "module_type": module_type,
                    "stage": stage,
                },
                ai_trial_history_params.AITrialHistoryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def relation(
        self,
        *,
        service_type: Literal[1, 2] | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问答联想

        Args:
          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-trial/relation",
            body=maybe_transform(
                {
                    "service_type": service_type,
                    "session_id": session_id,
                },
                ai_trial_relation_params.AITrialRelationParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def report(
        self,
        *,
        service_type: int,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        发布获取诊断报告任务

        Args:
          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-trial/report",
            body=maybe_transform(
                {
                    "service_type": service_type,
                    "session_id": session_id,
                },
                ai_trial_report_params.AITrialReportParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def session_start(
        self,
        *,
        content: str | NotGiven = NOT_GIVEN,
        service_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        流程开始

        Args:
          content: 用户主诉

          service_type: 1-猫狗 2-异宠

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-trial/session-start",
            body=maybe_transform(
                {
                    "content": content,
                    "service_type": service_type,
                },
                ai_trial_session_start_params.AITrialSessionStartParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def summary(
        self,
        *,
        service_type: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取病情小结(流式)

        Args:
          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-trial/summary",
            body=maybe_transform(
                {
                    "service_type": service_type,
                    "session_id": session_id,
                },
                ai_trial_summary_params.AITrialSummaryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAITrialResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAITrialResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAITrialResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAITrialResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncAITrialResourceWithStreamingResponse(self)

    async def answer(
        self,
        *,
        service_type: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        user_input: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        AI 聊天

        Args:
          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          user_input: 用户输入

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return await self._post(
            "/ai-trial/answer",
            body=await async_maybe_transform(
                {
                    "service_type": service_type,
                    "session_id": session_id,
                    "user_input": user_input,
                },
                ai_trial_answer_params.AITrialAnswerParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def history(
        self,
        *,
        content: str,
        role: str,
        session_id: str,
        content_type: int | NotGiven = NOT_GIVEN,
        module_type: int | NotGiven = NOT_GIVEN,
        stage: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        保存聊天记录

        Args:
          content: 内容

          role: 角色, 取值为其中之一 ==>[user, ai]

          session_id: 会话 id

          content_type: 1-文字 2-图文

          module_type: 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别

          stage: 1-用户主诉 2-用户回答 3-AI 提问 4-AI 病情小结 5-AI 病例报告 6-AI 输出 7-用户补充

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-trial/history",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "role": role,
                    "session_id": session_id,
                    "content_type": content_type,
                    "module_type": module_type,
                    "stage": stage,
                },
                ai_trial_history_params.AITrialHistoryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def relation(
        self,
        *,
        service_type: Literal[1, 2] | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问答联想

        Args:
          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-trial/relation",
            body=await async_maybe_transform(
                {
                    "service_type": service_type,
                    "session_id": session_id,
                },
                ai_trial_relation_params.AITrialRelationParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def report(
        self,
        *,
        service_type: int,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        发布获取诊断报告任务

        Args:
          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-trial/report",
            body=await async_maybe_transform(
                {
                    "service_type": service_type,
                    "session_id": session_id,
                },
                ai_trial_report_params.AITrialReportParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def session_start(
        self,
        *,
        content: str | NotGiven = NOT_GIVEN,
        service_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        流程开始

        Args:
          content: 用户主诉

          service_type: 1-猫狗 2-异宠

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-trial/session-start",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "service_type": service_type,
                },
                ai_trial_session_start_params.AITrialSessionStartParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def summary(
        self,
        *,
        service_type: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取病情小结(流式)

        Args:
          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-trial/summary",
            body=await async_maybe_transform(
                {
                    "service_type": service_type,
                    "session_id": session_id,
                },
                ai_trial_summary_params.AITrialSummaryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AITrialResourceWithRawResponse:
    def __init__(self, ai_trial: AITrialResource) -> None:
        self._ai_trial = ai_trial

        self.answer = to_raw_response_wrapper(
            ai_trial.answer,
        )
        self.history = to_raw_response_wrapper(
            ai_trial.history,
        )
        self.relation = to_raw_response_wrapper(
            ai_trial.relation,
        )
        self.report = to_raw_response_wrapper(
            ai_trial.report,
        )
        self.session_start = to_raw_response_wrapper(
            ai_trial.session_start,
        )
        self.summary = to_raw_response_wrapper(
            ai_trial.summary,
        )


class AsyncAITrialResourceWithRawResponse:
    def __init__(self, ai_trial: AsyncAITrialResource) -> None:
        self._ai_trial = ai_trial

        self.answer = async_to_raw_response_wrapper(
            ai_trial.answer,
        )
        self.history = async_to_raw_response_wrapper(
            ai_trial.history,
        )
        self.relation = async_to_raw_response_wrapper(
            ai_trial.relation,
        )
        self.report = async_to_raw_response_wrapper(
            ai_trial.report,
        )
        self.session_start = async_to_raw_response_wrapper(
            ai_trial.session_start,
        )
        self.summary = async_to_raw_response_wrapper(
            ai_trial.summary,
        )


class AITrialResourceWithStreamingResponse:
    def __init__(self, ai_trial: AITrialResource) -> None:
        self._ai_trial = ai_trial

        self.answer = to_streamed_response_wrapper(
            ai_trial.answer,
        )
        self.history = to_streamed_response_wrapper(
            ai_trial.history,
        )
        self.relation = to_streamed_response_wrapper(
            ai_trial.relation,
        )
        self.report = to_streamed_response_wrapper(
            ai_trial.report,
        )
        self.session_start = to_streamed_response_wrapper(
            ai_trial.session_start,
        )
        self.summary = to_streamed_response_wrapper(
            ai_trial.summary,
        )


class AsyncAITrialResourceWithStreamingResponse:
    def __init__(self, ai_trial: AsyncAITrialResource) -> None:
        self._ai_trial = ai_trial

        self.answer = async_to_streamed_response_wrapper(
            ai_trial.answer,
        )
        self.history = async_to_streamed_response_wrapper(
            ai_trial.history,
        )
        self.relation = async_to_streamed_response_wrapper(
            ai_trial.relation,
        )
        self.report = async_to_streamed_response_wrapper(
            ai_trial.report,
        )
        self.session_start = async_to_streamed_response_wrapper(
            ai_trial.session_start,
        )
        self.summary = async_to_streamed_response_wrapper(
            ai_trial.summary,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from czlai.types import (
    UserModuleUsageGetAddWecomeBonusResponse,
    UserModuleUsageGetWechatMiniQrcodeResponse,
)
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestUserModuleUsages:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_checkin(self, client: Czlai) -> None:
        user_module_usage = client.user_module_usages.checkin()
        assert user_module_usage is None

    @parametrize
    def test_raw_response_checkin(self, client: Czlai) -> None:
        response = client.user_module_usages.with_raw_response.checkin()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user_module_usage = response.parse()
        assert user_module_usage is None

    @parametrize
    def test_streaming_response_checkin(self, client: Czlai) -> None:
        with client.user_module_usages.with_streaming_response.checkin() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user_module_usage = response.parse()
            assert user_module_usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_get_add_wecome_bonus(self, client: Czlai) -> None:
        user_module_usage = client.user_module_usages.get_add_wecome_bonus()
        assert_matches_type(UserModuleUsageGetAddWecomeBonusResponse, user_module_usage, path=["response"])

    @parametrize
    def test_method_get_add_wecome_bonus_with_all_params(self, client: Czlai) -> None:
        user_module_usage = client.user_module_usages.get_add_wecome_bonus(
            module_type=0,
        )
        assert_matches_type(UserModuleUsageGetAddWecomeBonusResponse, user_module_usage, path=["response"])

    @parametrize
    def test_raw_response_get_add_wecome_bonus(self, client: Czlai) -> None:
        response = client.user_module_usages.with_raw_response.get_add_wecome_bonus()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user_module_usage = response.parse()
        assert_matches_type(UserModuleUsageGetAddWecomeBonusResponse, user_module_usage, path=["response"])

    @parametrize
    def test_streaming_response_get_add_wecome_bonus(self, client: Czlai) -> None:
        with client.user_module_usages.with_streaming_response.get_add_wecome_bonus() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user_module_usage = response.parse()
            assert_matches_type(UserModuleUsageGetAddWecomeBonusResponse, user_module_usage, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_get_wechat_mini_qrcode(self, client: Czlai) -> None:
        user_module_usage = client.user_module_usages.get_wechat_mini_qrcode()
        assert_matches_type(UserModuleUsageGetWechatMiniQrcodeResponse, user_module_usage, path=["response"])

    @parametrize
    def test_raw_response_get_wechat_mini_qrcode(self, client: Czlai) -> None:
        response = client.user_module_usages.with_raw_response.get_wechat_mini_qrcode()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user_module_usage = response.parse()
        assert_matches_type(UserModuleUsageGetWechatMiniQrcodeResponse, user_module_usage, path=["response"])

    @parametrize
    def test_streaming_response_get_wechat_mini_qrcode(self, client: Czlai) -> None:
        with client.user_module_usages.with_streaming_response.get_wechat_mini_qrcode() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user_module_usage = response.parse()
            assert_matches_type(UserModuleUsageGetWechatMiniQrcodeResponse, user_module_usage, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncUserModuleUsages:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_checkin(self, async_client: AsyncCzlai) -> None:
        user_module_usage = await async_client.user_module_usages.checkin()
        assert user_module_usage is None

    @parametrize
    async def test_raw_response_checkin(self, async_client: AsyncCzlai) -> None:
        response = await async_client.user_module_usages.with_raw_response.checkin()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user_module_usage = await response.parse()
        assert user_module_usage is None

    @parametrize
    async def test_streaming_response_checkin(self, async_client: AsyncCzlai) -> None:
        async with async_client.user_module_usages.with_streaming_response.checkin() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user_module_usage = await response.parse()
            assert user_module_usage is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_get_add_wecome_bonus(self, async_client: AsyncCzlai) -> None:
        user_module_usage = await async_client.user_module_usages.get_add_wecome_bonus()
        assert_matches_type(UserModuleUsageGetAddWecomeBonusResponse, user_module_usage, path=["response"])

    @parametrize
    async def test_method_get_add_wecome_bonus_with_all_params(self, async_client: AsyncCzlai) -> None:
        user_module_usage = await async_client.user_module_usages.get_add_wecome_bonus(
            module_type=0,
        )
        assert_matches_type(UserModuleUsageGetAddWecomeBonusResponse, user_module_usage, path=["response"])

    @parametrize
    async def test_raw_response_get_add_wecome_bonus(self, async_client: AsyncCzlai) -> None:
        response = await async_client.user_module_usages.with_raw_response.get_add_wecome_bonus()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user_module_usage = await response.parse()
        assert_matches_type(UserModuleUsageGetAddWecomeBonusResponse, user_module_usage, path=["response"])

    @parametrize
    async def test_streaming_response_get_add_wecome_bonus(self, async_client: AsyncCzlai) -> None:
        async with async_client.user_module_usages.with_streaming_response.get_add_wecome_bonus() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user_module_usage = await response.parse()
            assert_matches_type(UserModuleUsageGetAddWecomeBonusResponse, user_module_usage, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_get_wechat_mini_qrcode(self, async_client: AsyncCzlai) -> None:
        user_module_usage = await async_client.user_module_usages.get_wechat_mini_qrcode()
        assert_matches_type(UserModuleUsageGetWechatMiniQrcodeResponse, user_module_usage, path=["response"])

    @parametrize
    async def test_raw_response_get_wechat_mini_qrcode(self, async_client: AsyncCzlai) -> None:
        response = await async_client.user_module_usages.with_raw_response.get_wechat_mini_qrcode()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        user_module_usage = await response.parse()
        assert_matches_type(UserModuleUsageGetWechatMiniQrcodeResponse, user_module_usage, path=["response"])

    @parametrize
    async def test_streaming_response_get_wechat_mini_qrcode(self, async_client: AsyncCzlai) -> None:
        async with async_client.user_module_usages.with_streaming_response.get_wechat_mini_qrcode() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            user_module_usage = await response.parse()
            assert_matches_type(UserModuleUsageGetWechatMiniQrcodeResponse, user_module_usage, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .is_add_wecome import (
    IsAddWecomeResource,
    AsyncIsAddWecomeResource,
    IsAddWecomeResourceWithRawResponse,
    AsyncIsAddWecomeResourceWithRawResponse,
    IsAddWecomeResourceWithStreamingResponse,
    AsyncIsAddWecomeResourceWithStreamingResponse,
)
from .user_module_usages import (
    UserModuleUsagesResource,
    AsyncUserModuleUsagesResource,
    UserModuleUsagesResourceWithRawResponse,
    AsyncUserModuleUsagesResourceWithRawResponse,
    UserModuleUsagesResourceWithStreamingResponse,
    AsyncUserModuleUsagesResourceWithStreamingResponse,
)

__all__ = [
    "IsAddWecomeResource",
    "AsyncIsAddWecomeResource",
    "IsAddWecomeResourceWithRawResponse",
    "AsyncIsAddWecomeResourceWithRawResponse",
    "IsAddWecomeResourceWithStreamingResponse",
    "AsyncIsAddWecomeResourceWithStreamingResponse",
    "UserModuleUsagesResource",
    "AsyncUserModuleUsagesResource",
    "UserModuleUsagesResourceWithRawResponse",
    "AsyncUserModuleUsagesResourceWithRawResponse",
    "UserModuleUsagesResourceWithStreamingResponse",
    "AsyncUserModuleUsagesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import point_detail_retrieve_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.point_detail_retrieve_response import PointDetailRetrieveResponse

__all__ = ["PointDetailsResource", "AsyncPointDetailsResource"]


class PointDetailsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PointDetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return PointDetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PointDetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return PointDetailsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        is_add: Literal[0, 1, 2] | NotGiven = NOT_GIVEN,
        limit: int | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PointDetailRetrieveResponse:
        """
        获取积分明细

        Args:
          is_add: 0-支出 1-收入 2-全部

          limit: 每页数量

          page: 页数

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/point-detail",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "is_add": is_add,
                        "limit": limit,
                        "page": page,
                    },
                    point_detail_retrieve_params.PointDetailRetrieveParams,
                ),
            ),
            cast_to=PointDetailRetrieveResponse,
        )


class AsyncPointDetailsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPointDetailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPointDetailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPointDetailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncPointDetailsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        is_add: Literal[0, 1, 2] | NotGiven = NOT_GIVEN,
        limit: int | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PointDetailRetrieveResponse:
        """
        获取积分明细

        Args:
          is_add: 0-支出 1-收入 2-全部

          limit: 每页数量

          page: 页数

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/point-detail",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "is_add": is_add,
                        "limit": limit,
                        "page": page,
                    },
                    point_detail_retrieve_params.PointDetailRetrieveParams,
                ),
            ),
            cast_to=PointDetailRetrieveResponse,
        )


class PointDetailsResourceWithRawResponse:
    def __init__(self, point_details: PointDetailsResource) -> None:
        self._point_details = point_details

        self.retrieve = to_raw_response_wrapper(
            point_details.retrieve,
        )


class AsyncPointDetailsResourceWithRawResponse:
    def __init__(self, point_details: AsyncPointDetailsResource) -> None:
        self._point_details = point_details

        self.retrieve = async_to_raw_response_wrapper(
            point_details.retrieve,
        )


class PointDetailsResourceWithStreamingResponse:
    def __init__(self, point_details: PointDetailsResource) -> None:
        self._point_details = point_details

        self.retrieve = to_streamed_response_wrapper(
            point_details.retrieve,
        )


class AsyncPointDetailsResourceWithStreamingResponse:
    def __init__(self, point_details: AsyncPointDetailsResource) -> None:
        self._point_details = point_details

        self.retrieve = async_to_streamed_response_wrapper(
            point_details.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from czlai.types import LoginResponse
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestLogins:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_sms(self, client: Czlai) -> None:
        login = client.logins.sms(
            code="123456",
            phone="phone",
        )
        assert_matches_type(LoginResponse, login, path=["response"])

    @parametrize
    def test_method_sms_with_all_params(self, client: Czlai) -> None:
        login = client.logins.sms(
            code="123456",
            phone="phone",
            login_from=0,
        )
        assert_matches_type(LoginResponse, login, path=["response"])

    @parametrize
    def test_raw_response_sms(self, client: Czlai) -> None:
        response = client.logins.with_raw_response.sms(
            code="123456",
            phone="phone",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        login = response.parse()
        assert_matches_type(LoginResponse, login, path=["response"])

    @parametrize
    def test_streaming_response_sms(self, client: Czlai) -> None:
        with client.logins.with_streaming_response.sms(
            code="123456",
            phone="phone",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            login = response.parse()
            assert_matches_type(LoginResponse, login, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_wechat(self, client: Czlai) -> None:
        login = client.logins.wechat(
            wechat_code="wechat_code",
        )
        assert login is None

    @parametrize
    def test_method_wechat_with_all_params(self, client: Czlai) -> None:
        login = client.logins.wechat(
            wechat_code="wechat_code",
            encrypted_data="encryptedData",
            iv="iv",
            module_type=0,
            phone_number="phone_number",
            spread_id=0,
        )
        assert login is None

    @parametrize
    def test_raw_response_wechat(self, client: Czlai) -> None:
        response = client.logins.with_raw_response.wechat(
            wechat_code="wechat_code",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        login = response.parse()
        assert login is None

    @parametrize
    def test_streaming_response_wechat(self, client: Czlai) -> None:
        with client.logins.with_streaming_response.wechat(
            wechat_code="wechat_code",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            login = response.parse()
            assert login is None

        assert cast(Any, response.is_closed) is True


class TestAsyncLogins:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_sms(self, async_client: AsyncCzlai) -> None:
        login = await async_client.logins.sms(
            code="123456",
            phone="phone",
        )
        assert_matches_type(LoginResponse, login, path=["response"])

    @parametrize
    async def test_method_sms_with_all_params(self, async_client: AsyncCzlai) -> None:
        login = await async_client.logins.sms(
            code="123456",
            phone="phone",
            login_from=0,
        )
        assert_matches_type(LoginResponse, login, path=["response"])

    @parametrize
    async def test_raw_response_sms(self, async_client: AsyncCzlai) -> None:
        response = await async_client.logins.with_raw_response.sms(
            code="123456",
            phone="phone",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        login = await response.parse()
        assert_matches_type(LoginResponse, login, path=["response"])

    @parametrize
    async def test_streaming_response_sms(self, async_client: AsyncCzlai) -> None:
        async with async_client.logins.with_streaming_response.sms(
            code="123456",
            phone="phone",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            login = await response.parse()
            assert_matches_type(LoginResponse, login, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_wechat(self, async_client: AsyncCzlai) -> None:
        login = await async_client.logins.wechat(
            wechat_code="wechat_code",
        )
        assert login is None

    @parametrize
    async def test_method_wechat_with_all_params(self, async_client: AsyncCzlai) -> None:
        login = await async_client.logins.wechat(
            wechat_code="wechat_code",
            encrypted_data="encryptedData",
            iv="iv",
            module_type=0,
            phone_number="phone_number",
            spread_id=0,
        )
        assert login is None

    @parametrize
    async def test_raw_response_wechat(self, async_client: AsyncCzlai) -> None:
        response = await async_client.logins.with_raw_response.wechat(
            wechat_code="wechat_code",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        login = await response.parse()
        assert login is None

    @parametrize
    async def test_streaming_response_wechat(self, async_client: AsyncCzlai) -> None:
        async with async_client.logins.with_streaming_response.wechat(
            wechat_code="wechat_code",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            login = await response.parse()
            assert login is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .pet_info import (
    PetInfoResource,
    AsyncPetInfoResource,
    PetInfoResourceWithRawResponse,
    AsyncPetInfoResourceWithRawResponse,
    PetInfoResourceWithStreamingResponse,
    AsyncPetInfoResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["PetsResource", "AsyncPetsResource"]


class PetsResource(SyncAPIResource):
    @cached_property
    def pet_info(self) -> PetInfoResource:
        return PetInfoResource(self._client)

    @cached_property
    def with_raw_response(self) -> PetsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return PetsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PetsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return PetsResourceWithStreamingResponse(self)


class AsyncPetsResource(AsyncAPIResource):
    @cached_property
    def pet_info(self) -> AsyncPetInfoResource:
        return AsyncPetInfoResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPetsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPetsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPetsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncPetsResourceWithStreamingResponse(self)


class PetsResourceWithRawResponse:
    def __init__(self, pets: PetsResource) -> None:
        self._pets = pets

    @cached_property
    def pet_info(self) -> PetInfoResourceWithRawResponse:
        return PetInfoResourceWithRawResponse(self._pets.pet_info)


class AsyncPetsResourceWithRawResponse:
    def __init__(self, pets: AsyncPetsResource) -> None:
        self._pets = pets

    @cached_property
    def pet_info(self) -> AsyncPetInfoResourceWithRawResponse:
        return AsyncPetInfoResourceWithRawResponse(self._pets.pet_info)


class PetsResourceWithStreamingResponse:
    def __init__(self, pets: PetsResource) -> None:
        self._pets = pets

    @cached_property
    def pet_info(self) -> PetInfoResourceWithStreamingResponse:
        return PetInfoResourceWithStreamingResponse(self._pets.pet_info)


class AsyncPetsResourceWithStreamingResponse:
    def __init__(self, pets: AsyncPetsResource) -> None:
        self._pets = pets

    @cached_property
    def pet_info(self) -> AsyncPetInfoResourceWithStreamingResponse:
        return AsyncPetInfoResourceWithStreamingResponse(self._pets.pet_info)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Required, TypedDict

__all__ = ["UserAdviceCreateParams"]


class UserAdviceCreateParams(TypedDict, total=False):
    advice_type: Required[str]
    """反馈类型"""

    description: Required[str]
    """反馈内容"""

    image_list: Required[List[str]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from czlai.types import (
    AIMemeCreateResponse,
    AIMemeGenerateResponse,
    AIMemeRetrieveResponse,
)
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAIMemes:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Czlai) -> None:
        ai_meme = client.ai_memes.create()
        assert_matches_type(AIMemeCreateResponse, ai_meme, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: Czlai) -> None:
        ai_meme = client.ai_memes.create(
            image_url="image_url",
            session_id="session_id",
        )
        assert_matches_type(AIMemeCreateResponse, ai_meme, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: Czlai) -> None:
        response = client.ai_memes.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_meme = response.parse()
        assert_matches_type(AIMemeCreateResponse, ai_meme, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: Czlai) -> None:
        with client.ai_memes.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_meme = response.parse()
            assert_matches_type(AIMemeCreateResponse, ai_meme, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: Czlai) -> None:
        ai_meme = client.ai_memes.retrieve()
        assert_matches_type(AIMemeRetrieveResponse, ai_meme, path=["response"])

    @parametrize
    def test_method_retrieve_with_all_params(self, client: Czlai) -> None:
        ai_meme = client.ai_memes.retrieve(
            limit=1,
            page=1,
        )
        assert_matches_type(AIMemeRetrieveResponse, ai_meme, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: Czlai) -> None:
        response = client.ai_memes.with_raw_response.retrieve()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_meme = response.parse()
        assert_matches_type(AIMemeRetrieveResponse, ai_meme, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: Czlai) -> None:
        with client.ai_memes.with_streaming_response.retrieve() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_meme = response.parse()
            assert_matches_type(AIMemeRetrieveResponse, ai_meme, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_generate(self, client: Czlai) -> None:
        ai_meme = client.ai_memes.generate()
        assert_matches_type(AIMemeGenerateResponse, ai_meme, path=["response"])

    @parametrize
    def test_method_generate_with_all_params(self, client: Czlai) -> None:
        ai_meme = client.ai_memes.generate(
            context_index=0,
            meme_id=0,
        )
        assert_matches_type(AIMemeGenerateResponse, ai_meme, path=["response"])

    @parametrize
    def test_raw_response_generate(self, client: Czlai) -> None:
        response = client.ai_memes.with_raw_response.generate()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_meme = response.parse()
        assert_matches_type(AIMemeGenerateResponse, ai_meme, path=["response"])

    @parametrize
    def test_streaming_response_generate(self, client: Czlai) -> None:
        with client.ai_memes.with_streaming_response.generate() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_meme = response.parse()
            assert_matches_type(AIMemeGenerateResponse, ai_meme, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncAIMemes:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncCzlai) -> None:
        ai_meme = await async_client.ai_memes.create()
        assert_matches_type(AIMemeCreateResponse, ai_meme, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_meme = await async_client.ai_memes.create(
            image_url="image_url",
            session_id="session_id",
        )
        assert_matches_type(AIMemeCreateResponse, ai_meme, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_memes.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_meme = await response.parse()
        assert_matches_type(AIMemeCreateResponse, ai_meme, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_memes.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_meme = await response.parse()
            assert_matches_type(AIMemeCreateResponse, ai_meme, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCzlai) -> None:
        ai_meme = await async_client.ai_memes.retrieve()
        assert_matches_type(AIMemeRetrieveResponse, ai_meme, path=["response"])

    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_meme = await async_client.ai_memes.retrieve(
            limit=1,
            page=1,
        )
        assert_matches_type(AIMemeRetrieveResponse, ai_meme, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_memes.with_raw_response.retrieve()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_meme = await response.parse()
        assert_matches_type(AIMemeRetrieveResponse, ai_meme, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_memes.with_streaming_response.retrieve() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_meme = await response.parse()
            assert_matches_type(AIMemeRetrieveResponse, ai_meme, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_generate(self, async_client: AsyncCzlai) -> None:
        ai_meme = await async_client.ai_memes.generate()
        assert_matches_type(AIMemeGenerateResponse, ai_meme, path=["response"])

    @parametrize
    async def test_method_generate_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_meme = await async_client.ai_memes.generate(
            context_index=0,
            meme_id=0,
        )
        assert_matches_type(AIMemeGenerateResponse, ai_meme, path=["response"])

    @parametrize
    async def test_raw_response_generate(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_memes.with_raw_response.generate()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_meme = await response.parse()
        assert_matches_type(AIMemeGenerateResponse, ai_meme, path=["response"])

    @parametrize
    async def test_streaming_response_generate(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_memes.with_streaming_response.generate() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_meme = await response.parse()
            assert_matches_type(AIMemeGenerateResponse, ai_meme, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["AITrialQuestionParams"]


class AITrialQuestionParams(TypedDict, total=False):
    service_type: int
    """1-猫狗 2-异宠"""

    session_id: str
    """会话 id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import policy_policy_info_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["PoliciesResource", "AsyncPoliciesResource"]


class PoliciesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PoliciesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return PoliciesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PoliciesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return PoliciesResourceWithStreamingResponse(self)

    def policy_info(
        self,
        *,
        keys: str | NotGiven = NOT_GIVEN,
        policy_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        政策类型

        Args:
          keys: 密钥

          policy_type: 1-用户协议 2-免责条款 3-隐私政策

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/policy/policy_info",
            body=maybe_transform(
                {
                    "keys": keys,
                    "policy_type": policy_type,
                },
                policy_policy_info_params.PolicyPolicyInfoParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncPoliciesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPoliciesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPoliciesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPoliciesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncPoliciesResourceWithStreamingResponse(self)

    async def policy_info(
        self,
        *,
        keys: str | NotGiven = NOT_GIVEN,
        policy_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        政策类型

        Args:
          keys: 密钥

          policy_type: 1-用户协议 2-免责条款 3-隐私政策

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/policy/policy_info",
            body=await async_maybe_transform(
                {
                    "keys": keys,
                    "policy_type": policy_type,
                },
                policy_policy_info_params.PolicyPolicyInfoParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class PoliciesResourceWithRawResponse:
    def __init__(self, policies: PoliciesResource) -> None:
        self._policies = policies

        self.policy_info = to_raw_response_wrapper(
            policies.policy_info,
        )


class AsyncPoliciesResourceWithRawResponse:
    def __init__(self, policies: AsyncPoliciesResource) -> None:
        self._policies = policies

        self.policy_info = async_to_raw_response_wrapper(
            policies.policy_info,
        )


class PoliciesResourceWithStreamingResponse:
    def __init__(self, policies: PoliciesResource) -> None:
        self._policies = policies

        self.policy_info = to_streamed_response_wrapper(
            policies.policy_info,
        )


class AsyncPoliciesResourceWithStreamingResponse:
    def __init__(self, policies: AsyncPoliciesResource) -> None:
        self._policies = policies

        self.policy_info = async_to_streamed_response_wrapper(
            policies.policy_info,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["MedicationAnalysisPicResultParams"]


class MedicationAnalysisPicResultParams(TypedDict, total=False):
    img_belong: int
    """图片归属(1:宠物体态分析、2:宠物表情分析、3:牙齿分析)"""

    img_url: str
    """图片 url"""

    pet_profile_id: int
    """宠物档案 id"""

    session_id: str
    """会话 id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import TypedDict

__all__ = ["WhitelistSaveDataParams"]


class WhitelistSaveDataParams(TypedDict, total=False):
    save_data: List[str]
    """保存数据"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["PetProfileDeleteParams"]


class PetProfileDeleteParams(TypedDict, total=False):
    pet_profile_id: Required[int]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Mapping, cast
from typing_extensions import Literal

import httpx

from ..types import upload_image_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven, FileTypes
from .._utils import (
    extract_files,
    maybe_transform,
    deepcopy_minimal,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["UploadImageResource", "AsyncUploadImageResource"]


class UploadImageResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UploadImageResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return UploadImageResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UploadImageResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return UploadImageResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        image: FileTypes,
        is_to_cloud: int | NotGiven = NOT_GIVEN,
        upload_type: Literal[1, 2, 3, 4] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        允许用户上传一张图片

        Args:
          image: 要上传的图片文件

          is_to_cloud: 是否上传到图床

          upload_type: 图片上传类型 1-头像 2-图片识别模块 3-表情包 4-其他

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        body = deepcopy_minimal({"image": image})
        files = extract_files(cast(Mapping[str, object], body), paths=[["image"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers["Content-Type"] = "multipart/form-data"
        return self._post(
            "/upload-image",
            body=maybe_transform(body, upload_image_create_params.UploadImageCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "is_to_cloud": is_to_cloud,
                        "upload_type": upload_type,
                    },
                    upload_image_create_params.UploadImageCreateParams,
                ),
            ),
            cast_to=NoneType,
        )


class AsyncUploadImageResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUploadImageResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncUploadImageResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUploadImageResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncUploadImageResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        image: FileTypes,
        is_to_cloud: int | NotGiven = NOT_GIVEN,
        upload_type: Literal[1, 2, 3, 4] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        允许用户上传一张图片

        Args:
          image: 要上传的图片文件

          is_to_cloud: 是否上传到图床

          upload_type: 图片上传类型 1-头像 2-图片识别模块 3-表情包 4-其他

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        body = deepcopy_minimal({"image": image})
        files = extract_files(cast(Mapping[str, object], body), paths=[["image"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers["Content-Type"] = "multipart/form-data"
        return await self._post(
            "/upload-image",
            body=await async_maybe_transform(body, upload_image_create_params.UploadImageCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "is_to_cloud": is_to_cloud,
                        "upload_type": upload_type,
                    },
                    upload_image_create_params.UploadImageCreateParams,
                ),
            ),
            cast_to=NoneType,
        )


class UploadImageResourceWithRawResponse:
    def __init__(self, upload_image: UploadImageResource) -> None:
        self._upload_image = upload_image

        self.create = to_raw_response_wrapper(
            upload_image.create,
        )


class AsyncUploadImageResourceWithRawResponse:
    def __init__(self, upload_image: AsyncUploadImageResource) -> None:
        self._upload_image = upload_image

        self.create = async_to_raw_response_wrapper(
            upload_image.create,
        )


class UploadImageResourceWithStreamingResponse:
    def __init__(self, upload_image: UploadImageResource) -> None:
        self._upload_image = upload_image

        self.create = to_streamed_response_wrapper(
            upload_image.create,
        )


class AsyncUploadImageResourceWithStreamingResponse:
    def __init__(self, upload_image: AsyncUploadImageResource) -> None:
        self._upload_image = upload_image

        self.create = async_to_streamed_response_wrapper(
            upload_image.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["PetInfoRetrieveParams"]


class PetInfoRetrieveParams(TypedDict, total=False):
    pets_type: Required[Literal["dog", "cat"]]
    """dog cat"""

    is_sort: Literal[0, 1]
    """0-分组 1-不分组"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["PointDetailRetrieveParams"]


class PointDetailRetrieveParams(TypedDict, total=False):
    is_add: Literal[0, 1, 2]
    """0-支出 1-收入 2-全部"""

    limit: int
    """每页数量"""

    page: int
    """页数"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

import httpx

from ..types import user_advice_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["UserAdvicesResource", "AsyncUserAdvicesResource"]


class UserAdvicesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UserAdvicesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return UserAdvicesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UserAdvicesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return UserAdvicesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        advice_type: str,
        description: str,
        image_list: List[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        用户反馈

        Args:
          advice_type: 反馈类型

          description: 反馈内容

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/user-advice",
            body=maybe_transform(
                {
                    "advice_type": advice_type,
                    "description": description,
                    "image_list": image_list,
                },
                user_advice_create_params.UserAdviceCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncUserAdvicesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUserAdvicesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncUserAdvicesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUserAdvicesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncUserAdvicesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        advice_type: str,
        description: str,
        image_list: List[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        用户反馈

        Args:
          advice_type: 反馈类型

          description: 反馈内容

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/user-advice",
            body=await async_maybe_transform(
                {
                    "advice_type": advice_type,
                    "description": description,
                    "image_list": image_list,
                },
                user_advice_create_params.UserAdviceCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class UserAdvicesResourceWithRawResponse:
    def __init__(self, user_advices: UserAdvicesResource) -> None:
        self._user_advices = user_advices

        self.create = to_raw_response_wrapper(
            user_advices.create,
        )


class AsyncUserAdvicesResourceWithRawResponse:
    def __init__(self, user_advices: AsyncUserAdvicesResource) -> None:
        self._user_advices = user_advices

        self.create = async_to_raw_response_wrapper(
            user_advices.create,
        )


class UserAdvicesResourceWithStreamingResponse:
    def __init__(self, user_advices: UserAdvicesResource) -> None:
        self._user_advices = user_advices

        self.create = to_streamed_response_wrapper(
            user_advices.create,
        )


class AsyncUserAdvicesResourceWithStreamingResponse:
    def __init__(self, user_advices: AsyncUserAdvicesResource) -> None:
        self._user_advices = user_advices

        self.create = async_to_streamed_response_wrapper(
            user_advices.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .ai_meme import AIMeme
from .._models import BaseModel

__all__ = ["AIMemeRetrieveResponse"]


class AIMemeRetrieveResponse(BaseModel):
    data: Optional[List[AIMeme]] = None

    message: Optional[str] = None

    success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .asr import (
    AsrResource,
    AsyncAsrResource,
    AsrResourceWithRawResponse,
    AsyncAsrResourceWithRawResponse,
    AsrResourceWithStreamingResponse,
    AsyncAsrResourceWithStreamingResponse,
)
from .users import (
    UsersResource,
    AsyncUsersResource,
    UsersResourceWithRawResponse,
    AsyncUsersResourceWithRawResponse,
    UsersResourceWithStreamingResponse,
    AsyncUsersResourceWithStreamingResponse,
)
from .contact import (
    ContactResource,
    AsyncContactResource,
    ContactResourceWithRawResponse,
    AsyncContactResourceWithRawResponse,
    ContactResourceWithStreamingResponse,
    AsyncContactResourceWithStreamingResponse,
)
from .summary import (
    SummaryResource,
    AsyncSummaryResource,
    SummaryResourceWithRawResponse,
    AsyncSummaryResourceWithRawResponse,
    SummaryResourceWithStreamingResponse,
    AsyncSummaryResourceWithStreamingResponse,
)
from .industry import (
    IndustryResource,
    AsyncIndustryResource,
    IndustryResourceWithRawResponse,
    AsyncIndustryResourceWithRawResponse,
    IndustryResourceWithStreamingResponse,
    AsyncIndustryResourceWithStreamingResponse,
)
from .user_info import (
    UserInfoResource,
    AsyncUserInfoResource,
    UserInfoResourceWithRawResponse,
    AsyncUserInfoResourceWithRawResponse,
    UserInfoResourceWithStreamingResponse,
    AsyncUserInfoResourceWithStreamingResponse,
)

__all__ = [
    "UserInfoResource",
    "AsyncUserInfoResource",
    "UserInfoResourceWithRawResponse",
    "AsyncUserInfoResourceWithRawResponse",
    "UserInfoResourceWithStreamingResponse",
    "AsyncUserInfoResourceWithStreamingResponse",
    "ContactResource",
    "AsyncContactResource",
    "ContactResourceWithRawResponse",
    "AsyncContactResourceWithRawResponse",
    "ContactResourceWithStreamingResponse",
    "AsyncContactResourceWithStreamingResponse",
    "SummaryResource",
    "AsyncSummaryResource",
    "SummaryResourceWithRawResponse",
    "AsyncSummaryResourceWithRawResponse",
    "SummaryResourceWithStreamingResponse",
    "AsyncSummaryResourceWithStreamingResponse",
    "AsrResource",
    "AsyncAsrResource",
    "AsrResourceWithRawResponse",
    "AsyncAsrResourceWithRawResponse",
    "AsrResourceWithStreamingResponse",
    "AsyncAsrResourceWithStreamingResponse",
    "IndustryResource",
    "AsyncIndustryResource",
    "IndustryResourceWithRawResponse",
    "AsyncIndustryResourceWithRawResponse",
    "IndustryResourceWithStreamingResponse",
    "AsyncIndustryResourceWithStreamingResponse",
    "UsersResource",
    "AsyncUsersResource",
    "UsersResourceWithRawResponse",
    "AsyncUsersResourceWithRawResponse",
    "UsersResourceWithStreamingResponse",
    "AsyncUsersResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from czlai.types import PointTaskListResponse
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestPointTasks:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_list(self, client: Czlai) -> None:
        point_task = client.point_tasks.list()
        assert_matches_type(PointTaskListResponse, point_task, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Czlai) -> None:
        response = client.point_tasks.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        point_task = response.parse()
        assert_matches_type(PointTaskListResponse, point_task, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Czlai) -> None:
        with client.point_tasks.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            point_task = response.parse()
            assert_matches_type(PointTaskListResponse, point_task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_bonus(self, client: Czlai) -> None:
        point_task = client.point_tasks.bonus()
        assert point_task is None

    @parametrize
    def test_method_bonus_with_all_params(self, client: Czlai) -> None:
        point_task = client.point_tasks.bonus(
            task_id=0,
        )
        assert point_task is None

    @parametrize
    def test_raw_response_bonus(self, client: Czlai) -> None:
        response = client.point_tasks.with_raw_response.bonus()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        point_task = response.parse()
        assert point_task is None

    @parametrize
    def test_streaming_response_bonus(self, client: Czlai) -> None:
        with client.point_tasks.with_streaming_response.bonus() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            point_task = response.parse()
            assert point_task is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_confirm(self, client: Czlai) -> None:
        point_task = client.point_tasks.confirm()
        assert point_task is None

    @parametrize
    def test_method_confirm_with_all_params(self, client: Czlai) -> None:
        point_task = client.point_tasks.confirm(
            task_id=0,
        )
        assert point_task is None

    @parametrize
    def test_raw_response_confirm(self, client: Czlai) -> None:
        response = client.point_tasks.with_raw_response.confirm()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        point_task = response.parse()
        assert point_task is None

    @parametrize
    def test_streaming_response_confirm(self, client: Czlai) -> None:
        with client.point_tasks.with_streaming_response.confirm() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            point_task = response.parse()
            assert point_task is None

        assert cast(Any, response.is_closed) is True


class TestAsyncPointTasks:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_list(self, async_client: AsyncCzlai) -> None:
        point_task = await async_client.point_tasks.list()
        assert_matches_type(PointTaskListResponse, point_task, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCzlai) -> None:
        response = await async_client.point_tasks.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        point_task = await response.parse()
        assert_matches_type(PointTaskListResponse, point_task, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCzlai) -> None:
        async with async_client.point_tasks.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            point_task = await response.parse()
            assert_matches_type(PointTaskListResponse, point_task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_bonus(self, async_client: AsyncCzlai) -> None:
        point_task = await async_client.point_tasks.bonus()
        assert point_task is None

    @parametrize
    async def test_method_bonus_with_all_params(self, async_client: AsyncCzlai) -> None:
        point_task = await async_client.point_tasks.bonus(
            task_id=0,
        )
        assert point_task is None

    @parametrize
    async def test_raw_response_bonus(self, async_client: AsyncCzlai) -> None:
        response = await async_client.point_tasks.with_raw_response.bonus()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        point_task = await response.parse()
        assert point_task is None

    @parametrize
    async def test_streaming_response_bonus(self, async_client: AsyncCzlai) -> None:
        async with async_client.point_tasks.with_streaming_response.bonus() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            point_task = await response.parse()
            assert point_task is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_confirm(self, async_client: AsyncCzlai) -> None:
        point_task = await async_client.point_tasks.confirm()
        assert point_task is None

    @parametrize
    async def test_method_confirm_with_all_params(self, async_client: AsyncCzlai) -> None:
        point_task = await async_client.point_tasks.confirm(
            task_id=0,
        )
        assert point_task is None

    @parametrize
    async def test_raw_response_confirm(self, async_client: AsyncCzlai) -> None:
        response = await async_client.point_tasks.with_raw_response.confirm()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        point_task = await response.parse()
        assert point_task is None

    @parametrize
    async def test_streaming_response_confirm(self, async_client: AsyncCzlai) -> None:
        async with async_client.point_tasks.with_streaming_response.confirm() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            point_task = await response.parse()
            assert point_task is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["MedicalRecord"]


class MedicalRecord(BaseModel):
    id: Optional[int] = None
    """主键 ID"""

    created_at: Optional[datetime] = None
    """创建时间"""

    module_type: Optional[int] = None
    """模块 1-智能问诊 2-健康检测"""

    report: Optional[str] = None
    """报告"""

    session_id: Optional[str] = None
    """对应的 session_id"""

    summary: Optional[str] = None
    """小结"""

    user_uuid: Optional[str] = None
    """用户 uuid"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ..types import (
    magnum_key_get_key_params,
    magnum_key_voice_choice_params,
    magnum_key_picture_choice_params,
    magnum_key_voice_question_params,
    magnum_key_picture_question_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["MagnumKeysResource", "AsyncMagnumKeysResource"]


class MagnumKeysResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MagnumKeysResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return MagnumKeysResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MagnumKeysResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return MagnumKeysResourceWithStreamingResponse(self)

    def get_key(
        self,
        *,
        context: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取 key_usage_id

        Args:
          context: 文本

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/magnumkey/get-key",
            body=maybe_transform({"context": context}, magnum_key_get_key_params.MagnumKeyGetKeyParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def picture_choice(
        self,
        *,
        img_url: str,
        key_usage_id: Optional[str] | NotGiven = NOT_GIVEN,
        user_uuid: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取图片选项

        Args:
          img_url: 图片 url

          key_usage_id: 会话 id

          user_uuid: 用户 uuid

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/magnumkey/picture-choice",
            body=maybe_transform(
                {
                    "img_url": img_url,
                    "key_usage_id": key_usage_id,
                    "user_uuid": user_uuid,
                },
                magnum_key_picture_choice_params.MagnumKeyPictureChoiceParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def picture_question(
        self,
        *,
        img_url: str,
        key_usage_id: Optional[str] | NotGiven = NOT_GIVEN,
        user_uuid: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取图片问题

        Args:
          img_url: 图片 url

          key_usage_id: 会话 id

          user_uuid: 用户 uuid

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/magnumkey/picture-question",
            body=maybe_transform(
                {
                    "img_url": img_url,
                    "key_usage_id": key_usage_id,
                    "user_uuid": user_uuid,
                },
                magnum_key_picture_question_params.MagnumKeyPictureQuestionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def voice_choice(
        self,
        *,
        message: str,
        key_usage_id: Optional[str] | NotGiven = NOT_GIVEN,
        user_uuid: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取声音选项

        Args:
          message: 获取声音选项

          key_usage_id: 会话 id

          user_uuid: 用户 uuid

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/magnumkey/voice-choice",
            body=maybe_transform(
                {
                    "message": message,
                    "key_usage_id": key_usage_id,
                    "user_uuid": user_uuid,
                },
                magnum_key_voice_choice_params.MagnumKeyVoiceChoiceParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def voice_question(
        self,
        *,
        message: str,
        key_usage_id: Optional[str] | NotGiven = NOT_GIVEN,
        pet_id: int | NotGiven = NOT_GIVEN,
        user_uuid: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取声音问题

        Args:
          message: 语音文本

          key_usage_id: 会话 id

          pet_id: 宠物 id

          user_uuid: 用户 uuid

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/magnumkey/voice-question",
            body=maybe_transform(
                {
                    "message": message,
                    "key_usage_id": key_usage_id,
                    "pet_id": pet_id,
                    "user_uuid": user_uuid,
                },
                magnum_key_voice_question_params.MagnumKeyVoiceQuestionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncMagnumKeysResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMagnumKeysResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMagnumKeysResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMagnumKeysResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncMagnumKeysResourceWithStreamingResponse(self)

    async def get_key(
        self,
        *,
        context: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取 key_usage_id

        Args:
          context: 文本

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/magnumkey/get-key",
            body=await async_maybe_transform({"context": context}, magnum_key_get_key_params.MagnumKeyGetKeyParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def picture_choice(
        self,
        *,
        img_url: str,
        key_usage_id: Optional[str] | NotGiven = NOT_GIVEN,
        user_uuid: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取图片选项

        Args:
          img_url: 图片 url

          key_usage_id: 会话 id

          user_uuid: 用户 uuid

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/magnumkey/picture-choice",
            body=await async_maybe_transform(
                {
                    "img_url": img_url,
                    "key_usage_id": key_usage_id,
                    "user_uuid": user_uuid,
                },
                magnum_key_picture_choice_params.MagnumKeyPictureChoiceParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def picture_question(
        self,
        *,
        img_url: str,
        key_usage_id: Optional[str] | NotGiven = NOT_GIVEN,
        user_uuid: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取图片问题

        Args:
          img_url: 图片 url

          key_usage_id: 会话 id

          user_uuid: 用户 uuid

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/magnumkey/picture-question",
            body=await async_maybe_transform(
                {
                    "img_url": img_url,
                    "key_usage_id": key_usage_id,
                    "user_uuid": user_uuid,
                },
                magnum_key_picture_question_params.MagnumKeyPictureQuestionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def voice_choice(
        self,
        *,
        message: str,
        key_usage_id: Optional[str] | NotGiven = NOT_GIVEN,
        user_uuid: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取声音选项

        Args:
          message: 获取声音选项

          key_usage_id: 会话 id

          user_uuid: 用户 uuid

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/magnumkey/voice-choice",
            body=await async_maybe_transform(
                {
                    "message": message,
                    "key_usage_id": key_usage_id,
                    "user_uuid": user_uuid,
                },
                magnum_key_voice_choice_params.MagnumKeyVoiceChoiceParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def voice_question(
        self,
        *,
        message: str,
        key_usage_id: Optional[str] | NotGiven = NOT_GIVEN,
        pet_id: int | NotGiven = NOT_GIVEN,
        user_uuid: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取声音问题

        Args:
          message: 语音文本

          key_usage_id: 会话 id

          pet_id: 宠物 id

          user_uuid: 用户 uuid

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/magnumkey/voice-question",
            body=await async_maybe_transform(
                {
                    "message": message,
                    "key_usage_id": key_usage_id,
                    "pet_id": pet_id,
                    "user_uuid": user_uuid,
                },
                magnum_key_voice_question_params.MagnumKeyVoiceQuestionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class MagnumKeysResourceWithRawResponse:
    def __init__(self, magnum_keys: MagnumKeysResource) -> None:
        self._magnum_keys = magnum_keys

        self.get_key = to_raw_response_wrapper(
            magnum_keys.get_key,
        )
        self.picture_choice = to_raw_response_wrapper(
            magnum_keys.picture_choice,
        )
        self.picture_question = to_raw_response_wrapper(
            magnum_keys.picture_question,
        )
        self.voice_choice = to_raw_response_wrapper(
            magnum_keys.voice_choice,
        )
        self.voice_question = to_raw_response_wrapper(
            magnum_keys.voice_question,
        )


class AsyncMagnumKeysResourceWithRawResponse:
    def __init__(self, magnum_keys: AsyncMagnumKeysResource) -> None:
        self._magnum_keys = magnum_keys

        self.get_key = async_to_raw_response_wrapper(
            magnum_keys.get_key,
        )
        self.picture_choice = async_to_raw_response_wrapper(
            magnum_keys.picture_choice,
        )
        self.picture_question = async_to_raw_response_wrapper(
            magnum_keys.picture_question,
        )
        self.voice_choice = async_to_raw_response_wrapper(
            magnum_keys.voice_choice,
        )
        self.voice_question = async_to_raw_response_wrapper(
            magnum_keys.voice_question,
        )


class MagnumKeysResourceWithStreamingResponse:
    def __init__(self, magnum_keys: MagnumKeysResource) -> None:
        self._magnum_keys = magnum_keys

        self.get_key = to_streamed_response_wrapper(
            magnum_keys.get_key,
        )
        self.picture_choice = to_streamed_response_wrapper(
            magnum_keys.picture_choice,
        )
        self.picture_question = to_streamed_response_wrapper(
            magnum_keys.picture_question,
        )
        self.voice_choice = to_streamed_response_wrapper(
            magnum_keys.voice_choice,
        )
        self.voice_question = to_streamed_response_wrapper(
            magnum_keys.voice_question,
        )


class AsyncMagnumKeysResourceWithStreamingResponse:
    def __init__(self, magnum_keys: AsyncMagnumKeysResource) -> None:
        self._magnum_keys = magnum_keys

        self.get_key = async_to_streamed_response_wrapper(
            magnum_keys.get_key,
        )
        self.picture_choice = async_to_streamed_response_wrapper(
            magnum_keys.picture_choice,
        )
        self.picture_question = async_to_streamed_response_wrapper(
            magnum_keys.picture_question,
        )
        self.voice_choice = async_to_streamed_response_wrapper(
            magnum_keys.voice_choice,
        )
        self.voice_question = async_to_streamed_response_wrapper(
            magnum_keys.voice_question,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["UserPointRetrieveResponse", "Data"]


class Data(BaseModel):
    bonus_point: Optional[str] = None
    """赠送的积分余额"""

    purchase_point: Optional[str] = None
    """购买的积分余额"""

    total_point: Optional[str] = None
    """总积分余额"""


class UserPointRetrieveResponse(BaseModel):
    data: Optional[Data] = None
